@@ -1,7 +1,7 @@
 '''
 nester.py contains the function print_lol
 '''
-def print_lol(the_list, depth):
+def print_lol(the_list, depth=0):
     '''
     print_lol is a function that takes a list and prints each element
     it takes a depth with default 0 paramater, for how many indents
